class RequestMiddleware(object):

    request = None

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        self.__class__.request = request

        return self.get_response(request)


